/*     MRC HEADER STRUCTURE
 *
 *     J. Brink
 *
 *     W.M. Keck Centre for Computational Biology
 *     Department of Biochemistry
 *     Baylor College of Medicine
 *     1 Baylor Plaza
 *     Houston, TX 77030, U.S.A.
 *
 *     SOURCE: image.doc
 *
 */

#define MRC_EXTRA        29
#define MRC_NUM_LABELS   10
#define MRC_LABEL_SIZE   80

struct mrc {

  int    nx;            /* # of columns ( fastest changing in the map    */
  int    ny;            /* # of rows                                     */            
  int    nz;            /* # of sections (slowest changing in the map    */

  int    mode;          /* data type
			      0 = image data in bytes
			      1 = image data in short integer
			      2 = image data in floats
			      3 = complex data in complex short integers
			      4 = complex data in complex reals          */

  int    nxstart;       /* number of first column in map (default = 0)   */
  int    nystart;       /* number of first row in map (default = 0)      */
  int    nzstart;       /* number of first ssection in map (default = 0) */

  int    mx;            /* number of intervals along X                   */
  int    my;            /* number of intervals along Y                   */
  int    mz;            /* number of intervals along Z                   */

  float  xlength;       /* cell dimensions in X (angstrom)               */
  float  ylength;       /* cell dimensions in Y (angstrom)               */
  float  zlength;       /* cell dimensions in Z (angstrom)               */

  float  alpha;         /* cell angles between Y and Z                   */
  float  beta;          /* cell angles between X and Z                   */
  float  gamma;         /* cell angles between X and Y                   */

  int    mapc;          /* number of axis corresponding to columns (X)   */
  int    mapr;          /* number of axis corresponding to rows (Y)      */
  int    maps;          /* number of axis corresponding to sections (Z)  */

  float  amin;          /* minimum density value                         */
  float  amax;          /* maximum density value                         */
  float  amean;         /* mean density value                            */

  int    ispg;          /* space group number (0 for images)             */
  int    nsymbt;        /* # of bytes for symmetry operators             */

  int    extra[MRC_EXTRA];     /* user defined storage space             */

  float  xorigin;       /* X phase origin                                */
  float  yorigin;       /* Y phase origin                                */

  int    nlabl;         /* # of labels being used in the MRC header      */

  char   label[MRC_NUM_LABELS][MRC_LABEL_SIZE]; /* actual text labels    */

/*
 * NOTE: In some cases what follows the MRC header are symmetry records stored as
 *       text as in the International Tables operators. These are separated by 
 *       a * and grouped into 'lines' of 80 characters.
 */

};
